@@ -98,7 +98,10 @@ IPv6Widget::IPv6Widget(const NetworkManager::Setting::Ptr &setting, QWidget* par
 
     connect(m_ui->btnRoutes, &QPushButton::clicked, this, &IPv6Widget::slotRoutesDialog);
 
-    // Validation
+    // Connect for setting check
+    watchChangedSetting();
+
+    // Connect for validity check
     connect(m_ui->dns, &KLineEdit::textChanged, this, &IPv6Widget::slotWidgetChanged);
     connect(m_ui->method, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &IPv6Widget::slotWidgetChanged);
     connect(&d->model, &QStandardItemModel::dataChanged, this, &IPv6Widget::slotWidgetChanged);
@@ -257,9 +260,8 @@ void IPv6Widget::slotModeComboChanged(int index)
         m_ui->privacyCombo->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == AutomaticOnlyIP) {
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(true);
@@ -270,9 +272,8 @@ void IPv6Widget::slotModeComboChanged(int index)
         m_ui->privacyCombo->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == Manual) {  // Manual
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(true);
@@ -283,9 +284,8 @@ void IPv6Widget::slotModeComboChanged(int index)
         m_ui->privacyCombo->setEnabled(true);
         m_ui->btnRoutes->setEnabled(true);
         m_ui->tableViewAddresses->setEnabled(true);
-        m_ui->tableViewAddresses->setVisible(true);
-        m_ui->btnAdd->setVisible(true);
-        m_ui->btnRemove->setVisible(true);
+        m_ui->btnAdd->setEnabled(true);
+        m_ui->btnRemove->setEnabled(true);
     } else if (index == AutomaticOnlyDHCP || index == LinkLocal) {  // Link-local or DHCP
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(false);
@@ -296,9 +296,8 @@ void IPv6Widget::slotModeComboChanged(int index)
         m_ui->privacyCombo->setEnabled(true);
         m_ui->btnRoutes->setEnabled(false);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     } else if (index == Disabled) {  // Ignored
         m_ui->dnsLabel->setText(i18n("DNS Servers:"));
         m_ui->dns->setEnabled(false);
@@ -309,9 +308,8 @@ void IPv6Widget::slotModeComboChanged(int index)
         m_ui->privacyCombo->setEnabled(false);
         m_ui->btnRoutes->setEnabled(false);
         m_ui->tableViewAddresses->setEnabled(false);
-        m_ui->tableViewAddresses->setVisible(false);
-        m_ui->btnAdd->setVisible(false);
-        m_ui->btnRemove->setVisible(false);
+        m_ui->btnAdd->setEnabled(false);
+        m_ui->btnRemove->setEnabled(false);
     }
 }
 
